# -*- coding: utf-8 -*-

# Simple Type Data
INTEGER_VALUE = "([+|-]?\\d+)"
FLOAT_VALUE = "([+-]?\\d+\\.?\\d+)"
HEX_VALUE = "([0-9abcdefABCDEF]+)"
NOSPACE_VALUE = "([^\\s]+)"

# Special Type Data
VERSION_VALUE = "(\\d+(\\.\\d+){0,3})"
FQDN_VALUE = "([a-zA-Z\\d-]+(\\.[a-zA-Z\\d-]+)*)"
ABSOLUTE_PATH_VALUE = "((\\/[^/]+)+\\/?)"
OID_VALUE = "(\\d+(\\.\\d+)*)"
IPV4 = "(\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3})"
IPV4_VALUE = IPV4
LISTENING_PORT = "(\\d{1,5})"
IPV4_SERVICE = "({IPV4}:{LISTENING_PORT})".format(IPV4=IPV4, LISTENING_PORT=LISTENING_PORT)

# Datetime
YEAR_VALUE = "(\\d{4})"
MONTH_VALUE = "(\\d{2})"
DAY_VALUE = "(\\d{2})"
HOUR_VALUE = "(\\d{2})"
MINUTE_VALUE = "(\\d{2})"
SECOND_VALUE = "(\\d{2})"
MICROSECOND_VALUE = "(\\d{6,9})"
MONTH_SHORT_NAME_VALUE = "(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)"
DATE_SIMPLE_VALUE = "({YEAR_VALUE}{MONTH_VALUE}{DAY_VALUE})".format(YEAR_VALUE=YEAR_VALUE, MONTH_VALUE=MONTH_VALUE, DAY_VALUE=DAY_VALUE)
DATE_VALUE = "({YEAR_VALUE}-{MONTH_VALUE}-{DAY_VALUE})".format(YEAR_VALUE=YEAR_VALUE, MONTH_VALUE=MONTH_VALUE, DAY_VALUE=DAY_VALUE)
DATE_DMY_VALUE = "({DAY_VALUE}/{MONTH_SHORT_NAME_VALUE}/{YEAR_VALUE})".format(DAY_VALUE=DAY_VALUE, MONTH_SHORT_NAME_VALUE=MONTH_SHORT_NAME_VALUE, YEAR_VALUE=YEAR_VALUE)
DATE_YMD_VALUE = "{YEAR_VALUE}-{MONTH_VALUE}-{DAY_VALUE}".format(YEAR_VALUE=YEAR_VALUE, MONTH_VALUE=MONTH_VALUE, DAY_VALUE=DAY_VALUE)
TIME_SIMPLE_VALUE = "({HOUR_VALUE}{MINUTE_VALUE}{SECOND_VALUE})".format(HOUR_VALUE=HOUR_VALUE, MINUTE_VALUE=MINUTE_VALUE, SECOND_VALUE=SECOND_VALUE)
TIME_VALUE = "({HOUR_VALUE}:{MINUTE_VALUE}:{SECOND_VALUE})".format(HOUR_VALUE=HOUR_VALUE, MINUTE_VALUE=MINUTE_VALUE, SECOND_VALUE=SECOND_VALUE)
DATETIME_SIMPLE_VALUE = "({DATE_SIMPLE_VALUE}{TIME_SIMPLE_VALUE})".format(DATE_SIMPLE_VALUE=DATE_SIMPLE_VALUE, TIME_SIMPLE_VALUE=TIME_SIMPLE_VALUE)
DATETIME_VALUE = "({DATE_VALUE} {TIME_VALUE})".format(DATE_VALUE=DATE_VALUE, TIME_VALUE=TIME_VALUE)
TIMEZONE_VALUE = "([+|-]\\d{2}:?\\d{2})"


# Parameters
QUOTED_RAW_VALUE = "((\\\\\\\"|[^\\\"])*)"
QUOTED_VALUE = "(\"?{QUOTED_RAW_VALUE}\"?)".format(QUOTED_RAW_VALUE=QUOTED_RAW_VALUE)
NAME_VALUE = "([a-zA-Z_][a-zA-Z0-9-_]*)"
OPTION = "({NAME_VALUE}={QUOTED_VALUE})".format(NAME_VALUE=NAME_VALUE, QUOTED_VALUE=QUOTED_VALUE)


# Datetime with named groups
YEAR = "(?P<year>{YEAR_VALUE})".format(YEAR_VALUE=YEAR_VALUE)
MONTH = "(?P<month>{MONTH_VALUE})".format(MONTH_VALUE=MONTH_VALUE)
MONTH_SHORT_NAME = "(?P<month_short_name>{MONTH_SHORT_NAME_VALUE})".format(MONTH_SHORT_NAME_VALUE=MONTH_SHORT_NAME_VALUE)
DAY = "(?P<day>{DAY_VALUE})".format(DAY_VALUE=DAY_VALUE)
HOUR = "(?P<hour>{HOUR_VALUE})".format(HOUR_VALUE=HOUR_VALUE)
MINUTE = "(?P<minute>{MINUTE_VALUE})".format(MINUTE_VALUE=MINUTE_VALUE)
SECOND = "(?P<second>{SECOND_VALUE})".format(SECOND_VALUE=SECOND_VALUE)
MICROSECOND = "(?P<microsecond>{MICROSECOND_VALUE})".format(MICROSECOND_VALUE=MICROSECOND_VALUE)
DATE_SIMPLE = "(?P<date_simple>{YEAR}{MONTH}{DAY})".format(YEAR=YEAR, MONTH=MONTH, DAY=DAY)
DATE = "(?P<date>{YEAR}-{MONTH}-{DAY})".format(YEAR=YEAR, MONTH=MONTH, DAY=DAY)
DATE_DMY = "(?P<date_dmy>{DAY}/{MONTH_SHORT_NAME}/{YEAR})".format(YEAR=YEAR, MONTH_SHORT_NAME=MONTH_SHORT_NAME, DAY=DAY)
DATE_YMD = "(?P<date_ymd>{YEAR}-{MONTH}-{DAY})".format(YEAR=YEAR, MONTH=MONTH, DAY=DAY)
TIME_SIMPLE = "(?P<time_simple>{HOUR}{MINUTE}{SECOND})".format(HOUR=HOUR, MINUTE=MINUTE, SECOND=SECOND)
TIME = "(?P<time>{HOUR}:{MINUTE}:{SECOND})".format(HOUR=HOUR, MINUTE=MINUTE, SECOND=SECOND)
DATETIME_SIMPLE = "(?P<datetime_simple>{DATE_SIMPLE}{TIME_SIMPLE})".format(DATE_SIMPLE=DATE_SIMPLE, TIME_SIMPLE=TIME_SIMPLE)
DATETIME = "(?P<datetime>{DATE} {TIME})".format(DATE=DATE, TIME=TIME)
TIMEZONE = "(?P<timezone>(?P<timezone_flag>[+|-])(?P<timezone_hour>\\d{2}):?(?P<timezone_minute>\\d{2}))"
ISO_FORMAT_TIME_VALUE = "(\\[{DAY_VALUE}/{MONTH_SHORT_NAME_VALUE}/{YEAR_VALUE}:{HOUR_VALUE}:{MINUTE_VALUE}:{SECOND_VALUE} {TIMEZONE_VALUE}\\])".format(
    DAY_VALUE=DAY_VALUE,
    MONTH_SHORT_NAME_VALUE=MONTH_SHORT_NAME_VALUE,
    YEAR_VALUE=YEAR_VALUE,
    HOUR_VALUE=HOUR_VALUE,
    MINUTE_VALUE=MINUTE_VALUE,
    SECOND_VALUE=SECOND_VALUE,
    TIMEZONE_VALUE=TIMEZONE_VALUE,
    )
ISO_FORMAT_TIME_WITH_MICROSECOND_VALUE = "\\[({DAY_VALUE}/{MONTH_SHORT_NAME_VALUE}/{YEAR_VALUE}:{HOUR_VALUE}:{MINUTE_VALUE}:{SECOND_VALUE}(\\.{MICROSECOND_VALUE})? {TIMEZONE_VALUE})\\]".format(
    DAY_VALUE=DAY_VALUE,
    MONTH_SHORT_NAME_VALUE=MONTH_SHORT_NAME_VALUE,
    YEAR_VALUE=YEAR_VALUE,
    HOUR_VALUE=HOUR_VALUE,
    MINUTE_VALUE=MINUTE_VALUE,
    SECOND_VALUE=SECOND_VALUE,
    MICROSECOND_VALUE=MICROSECOND_VALUE,
    TIMEZONE_VALUE=TIMEZONE_VALUE,
    )
ISO_FORMAT_TIME = "(\\[(?P<datetime>{DATE_DMY}:{TIME} {TIMEZONE})\\])".format(
    DATE_DMY=DATE_DMY,
    TIME=TIME,
    TIMEZONE=TIMEZONE,
    )
ISO_FORMAT_TIME_WITH_MICROSECOND = "(\\[(?P<datetime>{DATE_DMY}:{TIME}\\.{MICROSECOND} {TIMEZONE})\\])".format(
    DATE_DMY=DATE_DMY,
    TIME=TIME,
    MICROSECOND=MICROSECOND,
    TIMEZONE=TIMEZONE,
    )
